%% Figure 5 - Reduced form and structural elasticities in response to idiosyncratic productivity shocks.
clear all
close all
clc
fprintf('Running: Figure_5_Elasticities_in_Response_to_Shocks\n');

%% Baseline model
load('Created_mat_files/baseline_no_tax');  % Run in whole economy

% Size of productivity shocks under which we compute the bias
shock_size_vec  = [0.01,0.50]; 
Nx              = length(shock_size_vec);

for xx=(1:Nx)
    %% A. Increase productivity of one firm in each market
    % Choosing a firm at random is the same as choosing the first firm as
    % productivities were randomly drawn
    select1                 =([ones(1,J);zeros(Mj_max-1,J)]==1); 
    
    z_ij1                  = z_ij;
    z_ij1(select1)         = z_ij(select1).*(1+shock_size_vec(xx));
    
    %% B. Solve sectoral equilibria
    % Storage for outputs
    what_ij1         = zeros(Mj_max,J);      % Wage
    for jj=(1:J)     % J regions
        z_i                     = z_ij1(1:Mj(jj),jj); % Isolate productivity vector in region
        eq0                     = fun_solve_market_Nash(z_i,param,val,glob,options);
        what_ij1(1:Mj(jj),jj)   = eq0.w_i;
    end
    
    %% C. Construct 'hat' terms
    what_j1          = sum(what_ij1.^(eta+1)).^(1/(eta+1));
    What1            = sum(what_j1.^(theta+1)).^(1/(theta+1));
    
    %% D. Compute varpibar and zbar
    zbar            = glob.zbar;
    varphibar       = glob.varphibar;
    
    %% E. Scale up objects
    omega   = zbar/varphibar^(1-alpha);
    % PARTIAL EQUILIBRIUM %%%%%%%%%%%%%%%%%%
    W1      = W ;  % [PE]
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    w_ij1   = omega^(1/(1+(1-alpha)*theta)) * W1^( ((1-alpha)*(theta-varphi)) / (1+(1-alpha)*theta) ) .* what_ij1;
    w_j1    = sum(w_ij1.^(eta+1)).^(1/(eta+1));
    n_ij1   = varphibar*bsxfun(@times,bsxfun(@rdivide,w_ij1,w_j1).^eta,(w_j1/W1).^theta).*(W1/1).^varphi;
    y_ij1   = zbar.*z_ij1.*n_ij1.^(alpha);
 
    % Employment, wage, share
    n_ij1_store(:,:,xx)     = n_ij1;
    w_ij1_store(:,:,xx)     = w_ij1;
    s_ij0_store(:,:,xx)     = s_ij;      % Initial share
    
end
 
%% Construct averages in bins for plotting
s_bin_width             = 0.05;
s_bins                  = [0:s_bin_width:1] ;
Nbins                   = numel(s_bins)-1;
e_rf                    = zeros(Nbins,length(shock_size_vec));  % Reduced form
e_st                    = zeros(Nbins,length(shock_size_vec));  % Structural
i                       = (z_ij>0) & (z_ij1~=z_ij);
eps_i                   = @(Cournot,s_i)  (Cournot==1).*((s_i.*(1/theta) + (1-s_i).*(1/eta)).^(-1)) + (Cournot==0).*(s_i.*theta+(1-s_i).*eta);
for xx=(1:Nx)
    % Unpack
    n_ij1           = n_ij1_store(:,:,xx);
    w_ij1           = w_ij1_store(:,:,xx);
    s_ij0           = s_ij0_store(:,:,xx);
    
    % Structural elasticities for each firm
    s_ij0           = s_ij0(i);
    e_st_ij         = eps_i(1,s_ij0);
    
    % Reduced form elasticities for each firm
    d_logn_ij       = log(n_ij1(i))-log(n_ij(i));
    d_logw_ij       = log(w_ij1(i))-log(w_ij(i));
    e_rf_ij         = d_logn_ij./d_logw_ij;
       
    % Compute mean in each bin of market share
    for kk = (1:Nbins)
        I              = (s_ij0>= s_bins(kk)) & (s_ij0<= s_bins(kk+1));
        e_rf(kk,xx)   = mean(e_rf_ij(I));   
        e_st(kk,xx)   = mean(e_st_ij(I));   
    end
end

% Mid-points of bins for plotting
splot       = [0,0.5*(s_bins(2:end)+s_bins(1:end-1)),1];
% End points
e_rf        = [eta*ones(1,length(shock_size_vec));e_rf;theta*ones(1,length(shock_size_vec))];
e_st        = [eta*ones(1,length(shock_size_vec));e_st;theta*ones(1,length(shock_size_vec))];

%% FIGURE 
f01     = figure('name','measured v true');
set(f01,'Pos',[433 652 1702 580]);
set(0,'defaultlinelinewidth',4);
set(0,'defaultlinemarkersize',14);
font    = 22;

subplot(1,2,1)
set(groot,'defaulttextinterpreter','latex');
set(groot,'defaultLegendInterpreter','latex');

svec        = [0:0.01:1];
estructural = ( (1/theta)*svec + (1/eta)*(1-svec)).^(-1);

plot(splot,e_rf(:,1),'b--');hold on;
plot(splot,e_rf(:,2),'r-.','markersize',20);hold on;
plot(svec,estructural,'k-');hold on;
plot(splot,[repmat(eta,length(splot))],'k:'); hold on;
plot(splot,[repmat(theta,length(splot))],'k:');
grid on;
hl=legend('Inferred elasticity from 1\% shock',...
    'Inferred elasticity from 50\% shock',...
    'True underlying structural elasticity $\varepsilon(s_i)$');
hXLabel=xlabel('Market share: $s_{ij}$','interpreter','latex');
hYLabel=ylabel('Labor supply elasticity','interpreter','latex');
xticks([0:0.2:1]);
xtickformat('%3.2f');
xlim([-0.01,1]);
title('A. Labor supply elasticities (model)')
set(gca,'FontSize'   , font, 'FontWeight' , 'bold' ,'ticklabelinterpreter','latex');
set(hl,'location','northeast','fontsize',18)
set(gca,'ytick',[theta,2,4,6,8,eta,12]);
set(gca,'yticklabel',{'$\theta$','2.0','4.0','6.0','8.0','$\eta$','12.0'});
ylim([0,12]);

subplot(1,2,2)
plot(splot,100*(e_rf(:,1)./e_st(:,1)-1)','b--');hold on;
plot(splot,100*(e_rf(:,2)./e_st(:,2)-1)','r-.','markersize',20);hold on;
grid on;
hl=legend('Bias under a 1\% shock',...
    'Bias under a  50\% shock' );
hXLabel=xlabel('Market share: $s_{ij}$','interpreter','latex');
hYLabel=ylabel('Percent bias','interpreter','latex');
xticks([0:0.2:1]);
xtickformat('%3.2f');
text(0.47,165,'Percent bias:','interpreter','latex',...
    'fontsize',24);
text(0.80,165,'{$\frac{\widehat{\epsilon}_{ij}-\varepsilon_{ij}}{\varepsilon_{ij}}$}','interpreter','latex',...
    'fontsize',32);
title('B. Bias of reduced form estimate')
set(gca,'FontSize'   , font, 'FontWeight' , 'bold' ,'ticklabelinterpreter','latex');
set(hl,'location','south')
ylim([0,200]);

print '-depsc' Created_figure_files/Figure_5_Elasticities_in_Response_to_Shocks_eps

return
 


