%% Figure 6: Pass-through and replication of Kline et al, (2018)
clear all
close all
clc
fprintf('Running: Figure_6_Passthrough_Replication\n');
load('Created_mat_files/baseline_no_tax');
options.solve_scale = 'N';

%% KPWZ REPLICATION PARAMETERS
% 1. SHOCK SIZE
shock_size      = 0.186;  % Shock size chosen by hand to match KPWZ dlogVAPW:
fprintf('Referred to in paper:\n');
fprintf('Shock for KPWZ experiment = %4.1f\n',100*shock_size);
% 2. SIZE CUT-OFF
% Choose such that mean size of firms above cut-off matches KPWZ
Max_cut                 = 50;
size_cutoff_big         = [1:1:Max_cut];
size_cutoff_mean_temp   = zeros(Max_cut,1);
% Compute mean size given each conjectured cut-off
for i=(1:Max_cut)
    n_ij_temp                   = n_ij ;
    short_dist                  = n_ij_temp(n_ij_temp>size_cutoff_big(i));
    size_cutoff_mean_temp(i)    = mean(short_dist);
end

% Choose size_cutoff off to hit KPWZ mean firm size
size_mean_target    = 61.83;            % Table 2
[~,I_cutoff]        = min(abs(size_cutoff_mean_temp-size_mean_target));
size_cutoff         = size_cutoff_big(I_cutoff);

%% PASS-THROUGH SIMULATIONS

for type = [2,1] 
rand('seed',1);

%% CHOOSE FIRMS FOR SHOCK AND SHOCK PRODUCTIVITY
z_ij1                   = z_ij;
switch type
    case 1  % KPWZ
        % 1. {Replicate KPWZ, (large shock, large firm)}
        % Randomly choose a firm from set of firms in the market
        % that meet the size cut-off
        % Shock = shock_size_big
        ok = 0;
        for jj = (1:J)
           for (ii=1:Mj(jj))
               if n_ij(ii,jj) > size_cutoff
                   z_ij1(ii,jj) = z_ij1(ii,jj)*(1+shock_size);
                   ok = ok+1;
                   break
               end
           end
        end
        assert(ok==J);
    case 2  % All firms, small shock
        % 2. Draw firm at random (same as choosing first firm)
        % Small, 1 percent shock to productivity
        z_ij1(1,:)          = z_ij1(1,:)*(1+0.01);
end

%% A. Solve sectoral equilibria
% Storage for outputs
what_ij1         = zeros(Mj_max,J);      % Wage
for jj=(1:J)     % J regions
    z_i                     = z_ij1(1:Mj(jj),jj); 
    eq0                     = fun_solve_market_Nash(z_i,param,val,glob,options);
    what_ij1(1:Mj(jj),jj)   = eq0.w_i;
end

%% B. Construct 'hat' terms
%%%%%~~~PARTIAL EQUILIBRIUM TO REPLICTE KPWZ~~~%%%%%
What1           = What;     % PE so keep What fixed

%% D. Compute varpibar and zbar
zbar            = glob.zbar;
varphibar       = glob.varphibar;

%% E. Scale up objects
omega   = zbar/varphibar^(1-alpha);     % Nuisance parameter
W1      = omega^(1/(1+(1-alpha)*varphi)) * What1^( (1+(1-alpha)*theta) / (1+(1-alpha)*varphi) ) ;
w_ij1   = omega^(1/(1+(1-alpha)*theta)) * W1^( ((1-alpha)*(theta-varphi)) / (1+(1-alpha)*theta) ) .* what_ij1;
w_j1    = sum(w_ij1.^(eta+1)).^(1/(eta+1));
n_ij1   = varphibar*bsxfun(@times,bsxfun(@rdivide,w_ij1,w_j1).^eta,(w_j1/W1).^theta).*(W1/1).^varphi;

%% F. Pass-through regressions
%__________________________________________________________________
i           = (z_ij>0) & (z_ij1~=z_ij);
I           = ones(size(n_ij(i)));
%__________________________________________________________________
% For computing pass-through at each firm for plots
sales_ij    = (1/(1-Delta)).*zbar.*z_ij.*n_ij.^alpha; %This is y_ij, or VA
sales_ij1   = (1/(1-Delta)).*zbar.*z_ij1.*n_ij1.^alpha;

logw_ij     = log(w_ij(i)); 
logw_ij1    = log(w_ij1(i));
dlogw_ij    = logw_ij1         -   logw_ij;

logvapw_ij   = log(sales_ij(i)./n_ij(i));
logvapw_ij1  = log(sales_ij1(i)./n_ij1(i));
dlogvapw_ij  = logvapw_ij1       -   logvapw_ij;
%__________________________________________________________________
% Computation of pass-through in same way as KPWZ
% 1. Inputs
level_w_ij                  = w_ij(i) ; 
level_w_ij1                 = w_ij1(i) ;
dlevel_w_ij                 = level_w_ij1         -   level_w_ij;
level_vapw_ij               = sales_ij(i)./n_ij(i) ;
level_vapw_ij1              = sales_ij1(i)./n_ij1(i) ;
dlevel_vapw_ij              = level_vapw_ij1       -   level_vapw_ij;
% 2. Regression
X                           = [dlevel_vapw_ij];
Beta_hat                    = (X'*X)\(X'*dlevel_w_ij);   % Sales per worker
big_b_dvapw                 = Beta_hat;
% 3. Converted into elasticity as per KPWZ
big_b_dvapw_elast           = Beta_hat*(mean(level_vapw_ij)/mean(level_w_ij))     ;
%__________________________________________________________________
% Print main results
if (type==1)
omega_i = n_ij(i)/sum(n_ij(i)); 
fprintf('mean(dlogvapw_ij) = %3.4f \t target = 0.13\n',mean(dlogvapw_ij));
fprintf('Pass-through = %3.3f\n',big_b_dvapw_elast);
end
%__________________________________________________________________
% Predicted pass-through from closed form - For Panel A
% Closed form for 'Direct Effect Gamma_ij'
Gamma_ij        = (s_ij(i)*(eta-theta) + theta*(eta+1)) ...
                   ./...
                  ( (1+(1+eta)*(1-s_ij(i))).*s_ij(i)*(eta-theta) + theta*(eta+1)); 
%__________________________________________________________________
% Compute means in market share bins for Panel A
PT_ij               = dlogw_ij./dlogvapw_ij;   % dlogw/dlogvapw (Total effect) 
share               = s_ij(i);
share_edge          = prctile(share,[1:5:100]);     % bins

% Computations
share_mean          = zeros(numel(share_edge)-1,1);
PT_mean             = zeros(numel(share_edge)-1,1);
Gamma_mean          = zeros(numel(share_edge)-1,1);
for ss = (1:numel(share_edge)-1)
    id              = (share>=share_edge(ss)) & (share<=share_edge(ss+1));
    share_mean(ss)  = mean(share(id));          % Mean market share in bin
    PT_mean(ss)     = mean(PT_ij(id));         % Mean of Total effect in bin
    Gamma_mean(ss)  = mean(Gamma_ij(id));       % Mean of Direct effect in bin
end 
%__________________________________________________________________
% Save
save(sprintf('Created_mat_files/Passthrough_results_type_%i',type),'big_b_dvapw_elast','dlogvapw_ij','size_cutoff_mean_temp',...
            'I_cutoff','size_cutoff','shock_size','dlevel_w_ij','dlevel_vapw_ij','level_vapw_ij','level_w_ij','share_mean',...
            'PT_mean','Gamma_mean');
%__________________________________________________________________
end    

%% Table A1: Wage pass-through experiment details (Appendix)
fid = fopen('Created_table_files/Table_A1_Wage_Passthrough_Experiment_Details.tex','w');
fprintf(fid,'\\begin{tabular}{lll}\n');
fprintf(fid,'\\toprule[2pt]\n');
fprintf(fid,'\\textbf{Description} & \\textbf{Model} & \\textbf{Data (KPZW)} \\\\ \n');
fprintf(fid,'\\midrule\n');
fprintf(fid,'\\textbf{Replication Targets} &   &  \\\\ \n');
fprintf(fid,'\\midrule\n');
fprintf(fid,'Log change in VAPW (VAPW=$\\widetilde{Z}\\tilde{z}_{ij}n_{ij}^{\\tilde{\\alpha}-1}$) & %3.2f & 0.13 \\\\ \n',  mean(dlogvapw_ij) );
fprintf(fid,'Mean firm size & %3.2f & 61.49  \\\\ \n', size_cutoff_mean_temp(I_cutoff) );
fprintf(fid,'\\midrule\n');
fprintf(fid,'\\textbf{Replication Parameters} &   &  \\\\ \n');
fprintf(fid,'\\midrule\n');
fprintf(fid,'Size cutoff (Employees) & %3.2f & \\\\ \n',  size_cutoff );
fprintf(fid,'Shock size  ($ dlog(\\tilde{z}_{ij})$) & %3.2f & \\\\ \n',   shock_size  );
fprintf(fid,'\\bottomrule \n');
fprintf(fid,'\\end{tabular}');
fclose(fid);

%% PASS-THROUGH FIGURE
clear; close all;

% Bins for distribution of pass-through
pass_through_bin_edge       = [0:0.1:1]; 
pass_through_bin_mid        = (1/2)*(pass_through_bin_edge(2:end)+pass_through_bin_edge(1:end-1));

% Distribution of pass_through rates - KPWZ Replication (blue dash)
load Created_mat_files/Passthrough_results_type_1;
firm_level_passthrough_1    = (dlevel_w_ij./dlevel_vapw_ij).*(level_vapw_ij./level_w_ij);
pass_through_count_1        = histc(firm_level_passthrough_1,pass_through_bin_edge);
pass_through_count_1(end-1) = pass_through_count_1(end-1)+pass_through_count_1(end);
pass_through_count_1        = pass_through_count_1(1:end-1);
pass_through_hist_1         = pass_through_count_1./sum(pass_through_count_1);
mean_1                      = mean(big_b_dvapw_elast);   % Mean pass-through
share_mean_1                = share_mean;

% Distribution of pass_through rates - All firms, small shock (red dash-dot)
load Created_mat_files/Passthrough_results_type_2;
firm_level_passthrough_2    = (dlevel_w_ij./dlevel_vapw_ij).*(level_vapw_ij./level_w_ij);
pass_through_count_2        = histc(firm_level_passthrough_2,pass_through_bin_edge);
pass_through_count_2(end-1) = pass_through_count_2(end-1)+pass_through_count_2(end);
pass_through_count_2        = pass_through_count_2(1:end-1);
pass_through_hist_2         = pass_through_count_2./sum(pass_through_count_2);
mean_2                      = mean(big_b_dvapw_elast);      % Mean pass-through
share_mean_2                = share_mean;

%% FIGURE
close all

f2      = figure('name','figure2','position',[-186 381 1643 521]);
font    = 18;
ms      = 10;
xmin    = 0.20;
ymax    = 0.60;
kpwz    = 0.47;     % Estimate of pass-through from KPWZ;

subplot(1,2,1);
plot(share_mean_2,PT_mean,'bs-','linewidth',3,'markersize',15);hold on;grid on;
plot(share_mean_2,Gamma_mean,'ro:','linewidth',3,'markersize',8);hold on;
l=legend('Total effect','Direct effect $(\Gamma_{ij})$','location','north');
title('A. Pass-through by payroll share (model)','fontsize',font,'interpreter','latex');
ytickformat('%3.2f');
xtickformat('%3.2f');
xlabel('Payroll share $s_{ij}$','fontsize',font,'interpreter','latex');
ylabel('Pass-through','fontsize',font,'interpreter','latex');
set(l,'interpreter','latex','location','NorthWest','fontsize',font); 
set(gca,'fontsize',font,'TickLabelInterpreter','latex');
set(gcf,'PaperPositionMode','auto');
ylim([0.2,1.02]);

subplot(1,2,2);
plot(mean_1,0.175,'bo--','linewidth',2,'markersize',ms+4);hold on;
plot(mean_2,0.09,'rx-.','linewidth',2,'markersize',ms+12);hold on;
plot([kpwz,kpwz],[0,1],'k-','linewidth',2);hold on;
plot(pass_through_bin_mid,pass_through_hist_1,'b--','linewidth',3,'markersize',ms);hold on;
plot(pass_through_bin_mid,pass_through_hist_2,'r-.','linewidth',3,'markersize',ms+4);hold on;
ylabel('Fraction of firms','fontsize',font,'interpreter','latex');
xlabel('Pass-through','fontsize',font,'interpreter','latex');
title('B. Distribution of pass-through (model vs. data)','fontsize',font,'interpreter','latex');
grid on;
ylim([0,ymax]);xlim([xmin,1]);
set(gca,'Xtick',[xmin:0.1:1]);
set(gca,'fontsize',font,'TickLabelInterpreter','latex');
set(gcf,'PaperPositionMode','auto');
l = legend('Replicate KPWZ (large shock, large firms)','Small shock, all firms',sprintf('KPWZ statistic (data): $%3.2f$',kpwz));
text(0.49,0.22,sprintf('Model statistic = $%3.2f$',mean_1),'interpreter','latex','fontsize',font-2,'color',rgb('Blue'));
text(0.55,0.05,sprintf('Model statistic = $%3.2f$',mean_2),'interpreter','latex','fontsize',font-2,'color',rgb('Red'));
ytickformat('%3.2f');
xtickformat('%3.2f');
set(l,'interpreter','latex','location','NorthWest','fontsize',font); 

set(gcf,'PaperPositionMode','auto');
print('-depsc','Created_figure_files/Figure_6_Passthrough_Replication_of_KPWZ_eps');


return

